import sys

_url = "lgf1.aaron.com"
def _hello():
    print("lgf2.aaron.com")
def get_info():
    print(f"get_info()中的'__name__':{__name__ }")
    return "aaron_luckly_boy"
def get_character():
    return "handsome"
def get_message():
    return "li zhuo bing is sb"
# print(f"输入的参数个数：{len(sys.argv)}")
# if len(sys.argv)==1:
#     print("未输入参数，程序退出！")
#     sys.exit(0)
# else:
#     print("程序的输入参数:",end=' ')
#     for item in sys.argv:
#         print(item,end=' ')
